@@ -76,15 +76,12 @@ main(int argc, char *argv[])
 	int sk,sk1,pf_class,lstn_sk,acpt_sk,acpt1_sk, flag;
 	struct msghdr outmessage;
         char *message = "hello, world!\n";
-        struct iovec iov;
 	struct sctp_sndrcvinfo *sinfo;
         int count;
 	char outcmsg[CMSG_SPACE(sizeof(struct sctp_sndrcvinfo))];
 	struct cmsghdr *cmsg;
         struct iovec out_iov;
-        char * buffer;
 	struct msghdr inmessage;
-        char * buffer_snd;
 	char * buffer_rcv;
         struct sockaddr_in conn_addr,lstn_addr,svr_addr;
         struct iovec iov_rcv;
@@ -125,8 +122,6 @@ main(int argc, char *argv[])
 	acpt_sk = test_accept(lstn_sk, (struct sockaddr *)&svr_addr, &len);
 
 	memset(&outmessage, 0, sizeof(outmessage));
-        buffer = malloc(REALLY_BIG);
-
         outmessage.msg_name = &conn_addr;
         outmessage.msg_namelen = sizeof(conn_addr);
         outmessage.msg_iov = &out_iov;
@@ -143,10 +138,7 @@ main(int argc, char *argv[])
 	sinfo = (struct sctp_sndrcvinfo *)CMSG_DATA(cmsg);
         memset(sinfo, 0x00, sizeof(struct sctp_sndrcvinfo));
 
-	iov.iov_base = buffer;
-        iov.iov_len = REALLY_BIG;
         outmessage.msg_iov->iov_base = message;
-
         outmessage.msg_iov->iov_len = strlen(message) + 1;
 
 	flag = MSG_NOSIGNAL;
@@ -279,8 +271,6 @@ main(int argc, char *argv[])
 	acpt_sk = test_accept(lstn_sk, (struct sockaddr *)&svr_addr, &len);
 
 	memset(&outmessage, 0, sizeof(outmessage));
-        buffer_snd = malloc(REALLY_BIG);
-
         outmessage.msg_name = &svr_addr;
         outmessage.msg_namelen = sizeof(svr_addr);
         outmessage.msg_iov = &out_iov;
@@ -297,10 +287,7 @@ main(int argc, char *argv[])
 	sinfo = (struct sctp_sndrcvinfo *)CMSG_DATA(cmsg);
         memset(sinfo, 0x00, sizeof(struct sctp_sndrcvinfo));
 
-	iov.iov_base = buffer_snd;
-        iov.iov_len = REALLY_BIG;
         outmessage.msg_iov->iov_base = message;
-
         outmessage.msg_iov->iov_len = strlen(message) + 1;
 
 	memset(&inmessage, 0, sizeof(inmessage));
